Two known issues::

 * Implementation compiles (with warning) but execution is untested.
 * Implementation does not use ``bp-util`` for argparsing and timing, getting it to run in a suite might be cumbersome...

